@@ -182,6 +182,16 @@ ces <- function(data, seasonality=c("none","simple","partial","full"),
         if(is.null(xreg)){
             xreg <- model$xreg;
         }
+        else{
+            if(is.null(model$xreg)){
+                xreg <- NULL;
+            }
+            else{
+                if(ncol(xreg)!=ncol(model$xreg)){
+                    xreg <- xreg[,colnames(model$xreg)];
+                }
+            }
+        }
         initialX <- model$initialX;
         persistenceX <- model$persistenceX;
         transitionX <- model$transitionX;
@@ -320,10 +330,6 @@ CreatorCES <- function(silentText=FALSE,...){
     environment(likelihoodFunction) <- environment();
     environment(ICFunction) <- environment();
 
-    nParam <- (1 + sum(modellags)*(initialType=="o") + A$number*A$estimate + B$number*B$estimate +
-                   nExovars * initialXEstimate +
-                   (updateX)*((nExovars^2)*FXEstimate + nExovars*gXEstimate));
-
     if(any(initialType=="o",A$estimate,B$estimate,initialXEstimate,FXEstimate,gXEstimate)){
         C <- NULL;
         # If we don't need to estimate A
@@ -386,17 +392,18 @@ CreatorCES <- function(silentText=FALSE,...){
 
         C <- res$solution;
         cfObjective <- res$objective;
+
+        # Parameters estimated + variance
+        nParam <- length(C) + 1;
     }
     else{
         C <- c(A$value,B$value,initialValue,initialX,transitionX,persistenceX);
         cfObjective <- CF(C);
+
+        # Only variance is estimated
+        nParam <- 1;
     }
-    if(multisteps){
-        cfType <- "aTFL";
-    }
-    else{
-        cfType <- "MSE";
-    }
+
     ICValues <- ICFunction(nParam=nParam,nParamIntermittent=nParamIntermittent,
                            C=C,Etype=Etype);
     ICs <- ICValues$ICs;
@@ -404,9 +411,6 @@ CreatorCES <- function(silentText=FALSE,...){
 
     bestIC <- ICs[ic];
 
-# Revert to the provided cost function
-    cfType <- cfTypeOriginal;
-
     return(list(cfObjective=cfObjective,C=C,ICs=ICs,bestIC=bestIC,nParam=nParam,logLik=logLik));
 }
 
@@ -715,8 +719,17 @@ CreatorCES <- function(silentText=FALSE,...){
                                       maxlag*(seasonality!="n") + maxlag*any(seasonality==c("f","s")));
         }
     }
+
     if(initialXEstimate){
         initialX <- matat[1,];
+        names(initialX) <- colnames(matat);
+    }
+
+    # Make initialX NULL if all xreg were dropped
+    if(length(initialX)==1){
+        if(initialX==0){
+            initialX <- NULL;
+        }
     }
 
     if(gXEstimate){
@@ -763,7 +776,7 @@ CreatorCES <- function(silentText=FALSE,...){
         }
     }
 
-# Right down the smoothing parameters
+    # Right down the smoothing parameters
     nCoefficients <- 0;
     if(A$estimate){
         A$value <- complex(real=C[1],imaginary=C[2]);
@@ -825,7 +838,7 @@ CreatorCES <- function(silentText=FALSE,...){
         errormeasures <- NA;
     }
 
-##### Print output #####
+    ##### Print output #####
     if(!silentText){
         if(any(abs(eigen(matF - vecg %*% matw)$values)>(1 + 1E-10))){
             if(bounds!="a"){
@@ -838,7 +851,7 @@ CreatorCES <- function(silentText=FALSE,...){
         }
     }
 
-##### Make a plot #####
+    ##### Make a plot #####
     if(!silentGraph){
         y.for.new <- y.for;
         y.high.new <- y.high;
@@ -861,7 +874,7 @@ CreatorCES <- function(silentText=FALSE,...){
         }
     }
 
-##### Return values #####
+    ##### Return values #####
     model <- list(model=modelname,timeElapsed=Sys.time()-startTime,
                   states=matvt,A=A$value,B=B$value,
                   persistence=vecg,transition=matF,
