@@ -91,14 +91,27 @@ sim.ssarima <- function(orders=list(ar=0,i=1,ma=1), lags=1,
                         obs=10, nsim=1,
                         frequency=1, AR=NULL, MA=NULL, constant=FALSE,
                         initial=NULL, bounds=c("admissible","none"),
-                        randomizer=c("rnorm","runif","rbeta","rt"),
+                        randomizer=c("rnorm","rt","rlaplace","rs"),
                         iprob=1, ...){
 # Function generates data using SSARIMA in Single Source of Error as a data generating process.
-#    Copyright (C) 2015 - 2016 Ivan Svetunkov
+#    Copyright (C) 2015 - Inf Ivan Svetunkov
 
-    bounds <- substring(bounds[1],1,1);
     randomizer <- randomizer[1];
     args <- list(...);
+    bounds <- bounds[1];
+    # If R decided that by "b" we meant "bounds", fix this!
+    if(is.numeric(bounds)){
+        args$b <- bounds;
+        bounds <- "u";
+    }
+
+    if(all(bounds!=c("n","a","none","admissible"))){
+        warning(paste0("Strange type of bounds provided: ",bounds,". Switching to 'admissible'."),
+                call.=FALSE);
+        bounds <- "a";
+    }
+
+    bounds <- substring(bounds[1],1,1);
 
     if(!is.null(orders)){
         ar.orders <- orders$ar;
@@ -538,54 +551,47 @@ elementsGenerator <- function(ar.orders=ar.orders, ma.orders=ma.orders, i.orders
         }
     }
 
-# If the chosen randomizer is not rnorm, rt and runif and no parameters are provided, change to rnorm.
-    if(all(randomizer!=c("rnorm","rlnorm","rt","runif")) & (length(args)==0)){
+    # If the chosen randomizer is not default and no parameters are provided, change to rnorm.
+    if(all(randomizer!=c("rnorm","rt","rlaplace","rs")) & (length(args)==0)){
         warning(paste0("The chosen randomizer - ",randomizer," - needs some arbitrary parameters! Changing to 'rnorm' now."),call.=FALSE);
         randomizer = "rnorm";
     }
 
-# Check if any argument was passed in dots
+    # Check if no argument was passed in dots
     if(length(args)==0){
-# Create vector of the errors
-        if(any(randomizer==c("rnorm","runif"))){
+        # Create vector of the errors
+        if(any(randomizer==c("rnorm","rlaplace","rs"))){
             materrors[,] <- eval(parse(text=paste0(randomizer,"(n=",nsim*obs,")")));
         }
-        else if(randomizer=="rlnorm"){
-            materrors[,] <- rlnorm(n=nsim*obs,0,0.01+(1-iprob));
-            materrors <- materrors - 1;
-        }
         else if(randomizer=="rt"){
-# The degrees of freedom are df = n - k.
+            # The degrees of freedom are df = n - k.
             materrors[,] <- rt(nsim*obs,obs-(persistenceLength + maxlag));
         }
 
-        if(randomizer!="rlnorm"){
-# Center errors just in case
-            materrors <- materrors - colMeans(materrors);
-# Change variance to make some sense. Errors should not be rediculously high and not too low.
-            materrors <- materrors * sqrt(abs(arrvt[1,1,]));
+        # Center errors just in case
+        materrors <- materrors - colMeans(materrors);
+        # Change variance to make some sense. Errors should not be rediculously high and not too low.
+        materrors <- materrors * sqrt(abs(colMeans(as.matrix(arrvt[1:maxlag,1,]))));
+        if(randomizer=="rs"){
+            materrors <- materrors / 4;
         }
     }
-# If arguments are passed, use them. WE ASSUME HERE THAT USER KNOWS WHAT HE'S DOING!
+    # If arguments are passed, use them. WE ASSUME HERE THAT USER KNOWS WHAT HE'S DOING!
     else{
         materrors[,] <- eval(parse(text=paste0(randomizer,"(n=",nsim*obs,",", toString(as.character(args)),")")));
         if(randomizer=="rbeta"){
-# Center the errors around 0
+            # Center the errors around 0
             materrors <- materrors - 0.5;
-# Make a meaningful variance of data. Something resembling to var=1.
-            materrors <- materrors / rep(sqrt(colMeans(materrors^2)) * sqrt(abs(arrvt[1,1,])),each=obs);
+            # Make a meaningful variance of data. Something resembling to var=1.
+            materrors <- materrors / rep(sqrt(colMeans(materrors^2)) *
+                                             sqrt(abs(colMeans(as.matrix(arrvt[1:maxlag,1,])))),each=obs);
         }
         else if(randomizer=="rt"){
-# Make a meaningful variance of data.
-            materrors <- materrors * rep(sqrt(abs(arrvt[1,1,])),each=obs);
-        }
-        else if(randomizer=="rlnorm"){
-            materrors <- materrors - 1;
+            # Make a meaningful variance of data.
+            materrors <- materrors * rep(sqrt(abs(colMeans(as.matrix(arrvt[1:maxlag,1,])))),each=obs);
         }
     }
 
-    veclikelihood <- -obs/2 *(log(2*pi*exp(1)) + log(colMeans(materrors^2)));
-
 # Generate ones for the possible intermittency
     if(all(iprob == 1)){
         matot[,] <- 1;
@@ -606,6 +612,23 @@ elementsGenerator <- function(ar.orders=ar.orders, ma.orders=ma.orders, i.orders
     arrvt <- simulateddata$arrvt;
     dimnames(arrvt) <- list(NULL,componentsNames,NULL);
 
+    if(any(randomizer==c("rnorm","rt"))){
+        veclikelihood <- -obs/2 *(log(2*pi*exp(1)) + log(colMeans(materrors^2)));
+    }
+    else if(randomizer=="rlaplace"){
+        veclikelihood <- -obs*(log(2*exp(1)) + log(colMeans(abs(materrors))));
+    }
+    else if(randomizer=="rs"){
+        veclikelihood <- -2*obs*(log(2*exp(1)) + log(0.5*colMeans(sqrt(abs(materrors)))));
+    }
+    else if(randomizer=="rlnorm"){
+        veclikelihood <- -obs/2 *(log(2*pi*exp(1)) + log(colMeans(materrors^2))) - colSums(log(matyt));
+    }
+    # If this is something unknown, forget about it
+    else{
+        veclikelihood <- NA;
+    }
+
     if(constantRequired){
         dimnames(arrvt)[[2]][persistenceLength] <- "Constant";
     }
